--[[
	Project: BookOfTheFallen
	Version: 1.0.0
	Author: NerfedWar (http://www.nerfedwar.net - nerfed.war@gmail.com)

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

]]

-- initialise globals
if not BOTF then BOTF = {} end
BOTF.Book = class()

-- Book class constructor
function BOTF.Book:init()

  -- @field create the context
  self.context = UI.CreateContext("BOTFUIContext")

  -- make sure we have a config store for the bookPosition x,y
  self:initConfig()

  -- some drag drop related stuff
  self.leftDown = false
  self.originalXDiff = 0
  self.originalYDiff = 0

  -- @field create the book icon
  self.bookIcon = UI.CreateFrame("Texture", "BOTFBookIcon", self.context)
  self.bookIcon:SetTexture("BOTF", "media/book_icon_1.png")
  self.bookIcon:ResizeToTexture()
  self.bookIcon:SetPoint("TOPLEFT", UIParent, "TOPLEFT", BOTF_CONFIG['bookIconPosition']['x'], BOTF_CONFIG['bookIconPosition']['y'])
  self.bookIcon:SetVisible(true)
  function self.bookIcon.Event:MouseIn()
     self:SetTexture("BOTF", "media/book_icon_2.png")
  end
  function self.bookIcon.Event:MouseOut()
     self:SetTexture("BOTF", "media/book_icon_1.png")
  end
  function self.bookIcon.Event:LeftDown()
    self.leftDown = true
    local mouse = Inspect.Mouse()
    self.originalXDiff = mouse.x - self:GetLeft()
    self.originalYDiff = mouse.y - self:GetTop()
  end
  function self.bookIcon.Event:LeftClick()
    BOTF.toggle()
  end
  function self.bookIcon.Event:LeftUp()
    self.leftDown = false
  end
  function self.bookIcon.Event:LeftUpoutside()
    self.leftDown = false
  end
  function self.bookIcon.Event:MouseMove(x, y)
    if not self.leftDown then
      return
    end
    self:SetPoint("TOPLEFT", UIParent, "TOPLEFT", x - self.originalXDiff, y - self.originalYDiff)
    BOTF_CONFIG['bookIconPosition']['x'] = x - self.originalXDiff
    BOTF_CONFIG['bookIconPosition']['y'] = y - self.originalYDiff
  end

  -- @field create the book cover
  self.bookFrame = UI.CreateFrame("Texture", "BOTFBookFrame", self.context)
  self.bookFrame:SetTexture("BOTF", "media/book_cover.png")
  self.bookFrame:ResizeToTexture()
  self.bookFrame:SetPoint("TOPLEFT", UIParent, "TOPLEFT", BOTF_CONFIG['bookPosition']['x'], BOTF_CONFIG['bookPosition']['y'])
  self.bookFrame:SetVisible(false)
  function self.bookFrame.Event:LeftDown()
    self.leftDown = true
    local mouse = Inspect.Mouse()
    self.originalXDiff = mouse.x - self:GetLeft()
    self.originalYDiff = mouse.y - self:GetTop()
  end
  function self.bookFrame.Event:LeftUp()
    self.leftDown = false
  end

  function self.bookFrame.Event:LeftUpoutside()
    self.leftDown = false
  end
  function self.bookFrame.Event:MouseMove(x, y)
    if not self.leftDown then
      return
    end
    self:SetPoint("TOPLEFT", UIParent, "TOPLEFT", x - self.originalXDiff, y - self.originalYDiff)
    BOTF_CONFIG['bookPosition']['x'] = x - self.originalXDiff
    BOTF_CONFIG['bookPosition']['y'] = y - self.originalYDiff
  end

  -- @field create the pagesFrame
  self.pagesFrame = UI.CreateFrame("Texture", "BOTFPagesFrame", self.bookFrame)
  self.pagesFrame:SetTexture("BOTF", "media/book_pages.png")
  self.pagesFrame:ResizeToTexture()
  self.pagesFrame:SetPoint("CENTER", self.bookFrame, "CENTER")
  self.pagesFrame:SetLayer(1)

  -- @field close button
  self.closeButton = UI.CreateFrame("Texture", "BOTFUICloseButton", self.bookFrame)
  self.closeButton:SetTexture("BOTF", "media/close_button_1.png")
  self.closeButton:ResizeToTexture()
  self.closeButton:SetPoint("TOPLEFT", self.bookFrame, "TOPLEFT", 730, 4)
  self.closeButton:SetLayer(2) -- make sure the close button is above the pagesLayer
  self.closeButton.bookObject = self -- store a reference to the Book so we can access it from the click event
  function self.closeButton.Event:MouseIn()
    self:SetTexture("BOTF", "media/close_button_2.png")
  end

  function self.closeButton.Event:MouseOut()
    self:SetTexture("BOTF", "media/close_button_1.png")
  end

  function self.closeButton.Event:LeftClick(a)
    self.bookObject:hide()
  end

  -- @field table of bookmark objects
  self.bookmarks = {}
  self.bookmarks['home'] = BOTF.Book.Bookmark(self, "Home", 22, 34, 57)
  self.bookmarks['summary'] = BOTF.Book.Bookmark(self, "Summary", 17, 788, 110)
  self.bookmarks['pvp'] = BOTF.Book.Bookmark(self, "PVP", 24, 805, 157)
  self.bookmarks['pve'] = BOTF.Book.Bookmark(self, "PVE", 24, 805, 207)
  self.bookmarks['details'] = BOTF.Book.Bookmark(self, "Details", 18, 798, 260)

  -- @field table of page objects (all pages must extend BOTF.Book.BasicPage, see NerfedUtils/class.lua for more info)
  self.pages = {}
  self.pages['home'] = BOTF.Book.Home(self)
  self.pages['summary'] = BOTF.Book.Summary(self)
  self.pages['pvp'] = BOTF.Book.PVP(self)
  self.pages['pve'] = BOTF.Book.PVE(self)
  self.pages['details'] = BOTF.Book.Detail(self)

end

-- init config vars
function BOTF.Book:initConfig()
  -- make sure we have a config store for the bookPosition x,y
  if not BOTF_CONFIG then BOTF_CONFIG = {} end
  if not BOTF_CONFIG['bookPosition'] then BOTF_CONFIG['bookPosition'] = {} end
  if not BOTF_CONFIG['bookPosition']['x'] then BOTF_CONFIG['bookPosition']['x'] = 0 end
  if not BOTF_CONFIG['bookPosition']['y'] then BOTF_CONFIG['bookPosition']['y'] = 0 end
  if not BOTF_CONFIG['bookIconPosition'] then BOTF_CONFIG['bookIconPosition'] = {} end
  if not BOTF_CONFIG['bookIconPosition']['x'] then BOTF_CONFIG['bookIconPosition']['x'] = 0 end
  if not BOTF_CONFIG['bookIconPosition']['y'] then BOTF_CONFIG['bookIconPosition']['y'] = 0 end
end

-- display the Book and the home page
function BOTF.Book:show()
  self:initConfig()
  self:setPage('home')
  self.bookFrame:SetPoint("TOPLEFT", UIParent, "TOPLEFT", BOTF_CONFIG['bookPosition']['x'], BOTF_CONFIG['bookPosition']['y'])
  self.bookFrame:SetVisible(true)
end

-- hide the Book
function BOTF.Book:hide()
  self.bookFrame:SetVisible(false)
end

-- set the page to display
-- @param the name of the page ('home', 'summary', 'pvp', 'pve', 'details')
function BOTF.Book:setPage(thePage, options)
  for _, v in pairs({ 'home', 'summary', 'pvp', 'pve', 'details' }) do
    if thePage == v then
      if options then
        self.pages[v]:show(options)
      else
        self.pages[v]:show()
      end
    elseif self.pages[v] then
      self.pages[v]:hide()
    end
  end
end
