--[[
	Project: BookOfTheFallen
	Version: 1.0.0
	Author: NerfedWar (http://www.nerfedwar.net - nerfed.war@gmail.com)
	
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
]] 

------------------------
--[[ PUBLIC MEMBERS ]]--
------------------------
BOTF.UI = {}

-------------------------
--[[ PRIVATE MEMBERS ]]--
-------------------------
local context = nil

-- book and pages frames
local bookCoverFrame = nil
local pagesFrame = nil
local summaryLifetime = nil
local summarySession = nil

-- pages bookmarks
local botf_bm = nil
local list_bm = nil
local detail_bm = nil

-- close button
local closeButton = nil

-- list page stuff
local currentListPage = 1
local recordsPerPage = 46
local listPageSortField = "name"
local listPageTextFrames = {}
local listPageTextHeader1 = nil
local listPageTextHeader2 = nil
local list_prev = nil
local list_next = nil
local odd_pnum = nil
local even_pnum = nil

-- detail page stuff
local name_plate = nil
local calling_plate = nil
local silhouette = nil

------------------------
--[[ PUBLIC METHODS ]]--
------------------------

-- display the UI
function BOTF.UI.show()
	bookCoverFrame:SetVisible(true)
	BOTF.UI.showHomePage()
end

-- hide the UI
function BOTF.UI.hide()
	bookCoverFrame:SetVisible(false)
end

-- hide the home page elements
function BOTF.UI.hideHomePage()

end

-- show home page
function BOTF.UI.showHomePage()

  	if not BOTF then return end

    -- set the background
	pagesFrame:SetTexture("BOTF", "media/book_home.png")
	pagesFrame:ResizeToTexture()

	-- hide elements from other pages
	for i=1,46,1 do listPageTextFrames[i]:SetVisible(false) end
	listPageTextHeader1:SetVisible(false)
	listPageTextHeader2:SetVisible(false)
	list_prev:SetVisible(false)
	list_next:SetVisible(false)
	odd_pnum:SetVisible(false)
	even_pnum:SetVisible(false)
	name_plate:SetVisible(false)
	calling_plate:SetVisible(false)
	silhouette:SetVisible(false)

	-- lifetime
	local Victory_SoloKills = 0
	local Victory_KillingBlows = 0
	local Victory_DamageAssists = 0
	local Victory_DistractAssists = 0
	local Victory_HealAssists = 0
	local Defeat_SoloKills = 0
	local Defeat_KillingBlows = 0
    local Defeat_DamageAssists = 0
    local Defeat_DistractAssists = 0
    local Defeat_HealAssists = 0
	-- session
	local sVictory_SoloKills = 0
	local sVictory_KillingBlows = 0
	local sVictory_DamageAssists = 0
	local sVictory_DistractAssists = 0
	local sVictory_HealAssists = 0
	local sDefeat_SoloKills = 0
	local sDefeat_KillingBlows = 0
    local sDefeat_DamageAssists = 0
    local sDefeat_DistractAssists = 0
    local sDefeat_HealAssists = 0
	for i,v in pairs(BOTF_DB) do

		if string.sub(i, 1, 2)~="__" then

			-- lifetime
			Victory_SoloKills=Victory_SoloKills+v.statistics.Victory_SoloKills
			Victory_KillingBlows=Victory_KillingBlows+v.statistics.Victory_KillingBlows
			Victory_DamageAssists=Victory_DamageAssists+v.statistics.Victory_DamageAssists
			Victory_DistractAssists=Victory_DistractAssists+v.statistics.Victory_DistractAssists
			Victory_HealAssists=Victory_HealAssists+v.statistics.Victory_HealAssists
            Defeat_SoloKills=Defeat_SoloKills+v.statistics.Defeat_SoloKills
            Defeat_KillingBlows=Defeat_KillingBlows+v.statistics.Defeat_KillingBlows
            Defeat_DamageAssists=Defeat_DamageAssists+v.statistics.Defeat_DamageAssists
            Defeat_DistractAssists=Defeat_DistractAssists+v.statistics.Defeat_DistractAssists
            Defeat_HealAssists=Defeat_HealAssists+v.statistics.Defeat_HealAssists
			-- session
			sVictory_SoloKills=sVictory_SoloKills+v.session_statistics.Victory_SoloKills
			sVictory_KillingBlows=sVictory_KillingBlows+v.session_statistics.Victory_KillingBlows
			sVictory_DamageAssists=sVictory_DamageAssists+v.session_statistics.Victory_DamageAssists
			sVictory_DistractAssists=sVictory_DistractAssists+v.session_statistics.Victory_DistractAssists
			sVictory_HealAssists=sVictory_HealAssists+v.session_statistics.Victory_HealAssists
            sDefeat_SoloKills=sDefeat_SoloKills+v.session_statistics.Defeat_SoloKills
            sDefeat_KillingBlows=sDefeat_KillingBlows+v.session_statistics.Defeat_KillingBlows
            sDefeat_DamageAssists=sDefeat_DamageAssists+v.session_statistics.Defeat_DamageAssists
            sDefeat_DistractAssists=sDefeat_DistractAssists+v.session_statistics.Defeat_DistractAssists
            sDefeat_HealAssists=sDefeat_HealAssists+v.session_statistics.Defeat_HealAssists

		end
	end
	local score = ((10*Victory_SoloKills)+Victory_KillingBlows+Victory_DamageAssists+Victory_DistractAssists+Victory_HealAssists)-((10*Defeat_SoloKills)+Defeat_KillingBlows+Defeat_DamageAssists+Defeat_DistractAssists+Defeat_HealAssists)
	local score_pad = 12
	if score>0 then
		score="+"..score
		score_pad=11
	elseif score<0 then
		score_pad=11
	end
	local lifetime_block = [[
Victories:	  Solo:	 		]]..string.lpad(Victory_SoloKills, 12, " ")..[[

                 Killing blows: 	]]..string.lpad(Victory_KillingBlows, 12, " ")..[[

		  Damage assists: 	]]..string.lpad(Victory_DamageAssists, 12, " ")..[[

		  Distract assists: 	]]..string.lpad(Victory_DistractAssists, 12, " ")..[[

		  Heal assists: 		]]..string.lpad(Victory_HealAssists, 12, " ")..[[

Defeats:	  Solo:	 		]]..string.lpad(Defeat_SoloKills, 12, " ")..[[

		  Killing blows: 		]]..string.lpad(Defeat_KillingBlows, 12, " ")..[[

		  Damage assists: 	]]..string.lpad(Defeat_DamageAssists, 12, " ")..[[

		  Distract assists: 	]]..string.lpad(Defeat_DistractAssists, 12, " ")..[[

		  Heal assists: 		]]..string.lpad(Defeat_HealAssists, 12, " ")..[[

Score: 		                      ]]..string.lpad(score, score_pad, " ")..[[
	]]
	local s_score = ((10*sVictory_SoloKills)+sVictory_KillingBlows+sVictory_DamageAssists+sVictory_DistractAssists+sVictory_HealAssists)-((10*sDefeat_SoloKills)+sDefeat_KillingBlows+sDefeat_DamageAssists+sDefeat_DistractAssists+sDefeat_HealAssists)
	local s_score_pad = 12
	if s_score>0 then
		s_score="+"..s_score
		s_score_pad=11
	elseif s_score<0 then
		s_score_pad=11
	end
	local session_block = [[
Victories:	  Solo:	 		]]..string.lpad(sVictory_SoloKills, 12, " ")..[[

                 Killing blows: 	]]..string.lpad(sVictory_KillingBlows, 12, " ")..[[

		  Damage assists: 	]]..string.lpad(sVictory_DamageAssists, 12, " ")..[[

		  Distract assists: 	]]..string.lpad(sVictory_DistractAssists, 12, " ")..[[

		  Heal assists: 		]]..string.lpad(sVictory_HealAssists, 12, " ")..[[

Defeats:	  Solo:	 		]]..string.lpad(sDefeat_SoloKills, 12, " ")..[[

		  Killing blows: 		]]..string.lpad(sDefeat_KillingBlows, 12, " ")..[[

		  Damage assists: 	]]..string.lpad(sDefeat_DamageAssists, 12, " ")..[[

		  Distract assists: 	]]..string.lpad(sDefeat_DistractAssists, 12, " ")..[[

		  Heal assists: 		]]..string.lpad(sDefeat_HealAssists, 12, " ")..[[

Score: 		                      ]]..string.lpad(score, score_pad, " ")..[[
	]]
	summaryLifetime:SetText(lifetime_block)
	summaryLifetime:SetVisible(true)
	summarySession:SetText(session_block)
	summarySession:SetVisible(true)
end

-- botf summary page
function BOTF.UI.showSummaryPage()

    -- set the background
	pagesFrame:SetTexture("BOTF", "media/book_home.png")
	pagesFrame:ResizeToTexture()
	
	-- hide elements from other pages
	for i=1,46,1 do listPageTextFrames[i]:SetVisible(false) end
	listPageTextHeader1:SetVisible(false)
	listPageTextHeader2:SetVisible(false)
	list_prev:SetVisible(false)
	list_next:SetVisible(false)
	odd_pnum:SetVisible(false)
	even_pnum:SetVisible(false)
	name_plate:SetVisible(false)
	calling_plate:SetVisible(false)
	silhouette:SetVisible(false)
	
	-- display summary page
	if not BOTF then return end
	
	-- lifetime
	local Victory_SoloKills = 0
	local Victory_KillingBlows = 0
	local Victory_DamageAssists = 0
	local Victory_DistractAssists = 0
	local Victory_HealAssists = 0
	local Defeat_SoloKills = 0
	local Defeat_KillingBlows = 0
    local Defeat_DamageAssists = 0
    local Defeat_DistractAssists = 0
    local Defeat_HealAssists = 0
	-- session
	local sVictory_SoloKills = 0
	local sVictory_KillingBlows = 0
	local sVictory_DamageAssists = 0
	local sVictory_DistractAssists = 0
	local sVictory_HealAssists = 0
	local sDefeat_SoloKills = 0
	local sDefeat_KillingBlows = 0
    local sDefeat_DamageAssists = 0
    local sDefeat_DistractAssists = 0
    local sDefeat_HealAssists = 0
	for i,v in pairs(BOTF_DB) do
	
		if string.sub(i, 1, 2)~="__" then
		
			-- lifetime
			Victory_SoloKills=Victory_SoloKills+v.statistics.Victory_SoloKills
			Victory_KillingBlows=Victory_KillingBlows+v.statistics.Victory_KillingBlows
			Victory_DamageAssists=Victory_DamageAssists+v.statistics.Victory_DamageAssists
			Victory_DistractAssists=Victory_DistractAssists+v.statistics.Victory_DistractAssists
			Victory_HealAssists=Victory_HealAssists+v.statistics.Victory_HealAssists
            Defeat_SoloKills=Defeat_SoloKills+v.statistics.Defeat_SoloKills
            Defeat_KillingBlows=Defeat_KillingBlows+v.statistics.Defeat_KillingBlows
            Defeat_DamageAssists=Defeat_DamageAssists+v.statistics.Defeat_DamageAssists
            Defeat_DistractAssists=Defeat_DistractAssists+v.statistics.Defeat_DistractAssists
            Defeat_HealAssists=Defeat_HealAssists+v.statistics.Defeat_HealAssists
			-- session
			sVictory_SoloKills=sVictory_SoloKills+v.session_statistics.Victory_SoloKills
			sVictory_KillingBlows=sVictory_KillingBlows+v.session_statistics.Victory_KillingBlows
			sVictory_DamageAssists=sVictory_DamageAssists+v.session_statistics.Victory_DamageAssists
			sVictory_DistractAssists=sVictory_DistractAssists+v.session_statistics.Victory_DistractAssists
			sVictory_HealAssists=sVictory_HealAssists+v.session_statistics.Victory_HealAssists
            sDefeat_SoloKills=sDefeat_SoloKills+v.session_statistics.Defeat_SoloKills
            sDefeat_KillingBlows=sDefeat_KillingBlows+v.session_statistics.Defeat_KillingBlows
            sDefeat_DamageAssists=sDefeat_DamageAssists+v.session_statistics.Defeat_DamageAssists
            sDefeat_DistractAssists=sDefeat_DistractAssists+v.session_statistics.Defeat_DistractAssists
            sDefeat_HealAssists=sDefeat_HealAssists+v.session_statistics.Defeat_HealAssists
		
		end
	end
    -- TODO: add defeats to calculation
	local score = (10*Victory_SoloKills)+Victory_KillingBlows+Victory_DamageAssists+Victory_DistractAssists+Victory_HealAssists
	local score_pad = 12
	if score>0 then 
		score="+"..score
		score_pad=11
	elseif score<0 then
		score_pad=11
	end
	local lifetime_block = [[
Victories:	  Solo:	 		]]..string.lpad(Victory_SoloKills, 12, " ")..[[

                 Killing blows: 	]]..string.lpad(Victory_KillingBlows, 12, " ")..[[

		  Damage assists: 	]]..string.lpad(Victory_DamageAssists, 12, " ")..[[

		  Distract assists: 	]]..string.lpad(Victory_DistractAssists, 12, " ")..[[

		  Heal assists: 		]]..string.lpad(Victory_HealAssists, 12, " ")..[[

Defeats:	  Solo:	 		]]..string.lpad(Defeat_SoloKills, 12, " ")..[[

		  Killing blows: 		]]..string.lpad(Defeat_KillingBlows, 12, " ")..[[

		  Damage assists: 	]]..string.lpad(Defeat_DamageAssists, 12, " ")..[[

		  Distract assists: 	]]..string.lpad(Defeat_DistractAssists, 12, " ")..[[

		  Heal assists: 		]]..string.lpad(Defeat_HealAssists, 12, " ")..[[

Score: 		                      ]]..string.lpad(score, score_pad, " ")..[[
	]]
	local s_score = (10*sVictory_SoloKills)+sVictory_KillingBlows+sVictory_DamageAssists+sVictory_DistractAssists+sVictory_HealAssists
	local s_score_pad = 12
	if s_score>0 then 
		s_score="+"..s_score
		s_score_pad=11
	elseif s_score<0 then
		s_score_pad=11
	end
	local session_block = [[
Victories:	  Solo:	 		]]..string.lpad(sVictory_SoloKills, 12, " ")..[[
		  Killing blows: 		]]..string.lpad(sVictory_KillingBlows, 12, " ")..[[
		  Damage assists: 	]]..string.lpad(sVictory_DamageAssists, 12, " ")..[[
		  Distract assists: 	]]..string.lpad(sVictory_DistractAssists, 12, " ")..[[
		  Heal assists: 		]]..string.lpad(sVictory_HealAssists, 12, " ")..[[

Defeats:	  Solo:	 		]]..string.lpad(sDefeat_SoloKills, 12, " ")..[[
		  Killing blows: 		]]..string.lpad(sDefeat_KillingBlows, 12, " ")..[[
		  Damage assists: 	]]..string.lpad(sDefeat_DamageAssists, 12, " ")..[[
		  Distract assists: 	]]..string.lpad(sDefeat_DistractAssists, 12, " ")..[[
		  Heal assists: 		]]..string.lpad(sDefeat_HealAssists, 12, " ")..[[
	]]
	summaryLifetime:SetText(lifetime_block)
	summaryLifetime:SetVisible(true)
	summarySession:SetText(session_block)
	summarySession:SetVisible(true)
end

-- list page
function BOTF.UI.showListPage(page)

	if page then
		currentListPage=page
	end

	-- display list background
	pagesFrame:SetTexture("BOTF", "media/book_list.png")
	pagesFrame:ResizeToTexture()
	
	-- hide elements from other pages
	summaryLifetime:SetVisible(false)
	summarySession:SetVisible(false)
	name_plate:SetVisible(false)
	calling_plate:SetVisible(false)
	silhouette:SetVisible(false)
	
	-- display list page
	listPageTextHeader1:SetVisible(true)
	listPageTextHeader2:SetVisible(true)
	for i=1,46,1 do listPageTextFrames[i]:SetVisible(true) end
	odd_pnum:SetVisible(true)
	even_pnum:SetVisible(true)
	
	-- loop through table
	local count = 1
	local totalCount = 1
	for i,v in orderedPairs(BOTF_DB) do
	
		if string.sub(i, 1, 2)~="__" then
		
			-- only output our page
			if totalCount>recordsPerPage*(currentListPage-1) and totalCount<=recordsPerPage*currentListPage then

				local score = (10*v.statistics.Victory_SoloKills)+v.statistics.Victory_DamageAssists+v.statistics.Victory_DistractAssists+v.statistics.Victory_HealAssists
				local frame = listPageTextFrames[count]
				local shortName = i
				if string.len(i)>13 then
					shortName=string.sub(i, 1, 13)
					shortName=string.rpad(shortName, 16, ".")
				end
				local isSession = "  "
				if BOTF_DB[i].session then
					isSession = "* "
				end
				frame:SetText(isSession..string.rpad(shortName, 17, " ")..string.rpad(v.calling, 7, " ")..string.rpad(v.level, 4, " ")..string.lpad(score, 4, " "))
				function frame.Event:LeftClick()
					BOTF.UI.showDetailPage(i)
				end
				function frame.Event:MouseIn()
					frame:SetFontColor(0.8,0.3,0.3,0.8)
				end
				function frame.Event:MouseOut()
					frame:SetFontColor(0.4,0.3,0.3,0.8)
				end
				count=count+1
			else
				local frame = listPageTextFrames[count]
				frame:SetText("")
			end

			totalCount=totalCount+1
		end
		
	end	
	
	-- prev and next buttons
	if currentListPage ~= 1 then
		list_prev:SetVisible(true)
		function list_prev.Event:LeftClick()
		   BOTF.UI.showListPage(currentListPage-1)
		end
	else
		list_prev:SetVisible(false)
	end
	local totalPages = (totalCount-1)/recordsPerPage
	if totalPages>currentListPage then
		list_next:SetVisible(true)
		function list_next.Event:LeftClick()
		   BOTF.UI.showListPage(currentListPage+1)
		end
	else
		list_next:SetVisible(false)
	end
	
	-- page numbers
	odd_pnum:SetText("Page "..(currentListPage*2)-1)
	even_pnum:SetText("Page "..(currentListPage*2))
end

-- detail page
function BOTF.UI.showDetailPage(name)
	pagesFrame:SetTexture("BOTF", "media/book_details.png")
	pagesFrame:ResizeToTexture()
	-- hide elements from other pages
	summaryLifetime:SetVisible(false)
	summarySession:SetVisible(false)
	listPageTextHeader1:SetVisible(false)
	listPageTextHeader2:SetVisible(false)
	list_prev:SetVisible(false)
	list_next:SetVisible(false)
	odd_pnum:SetVisible(false)
	even_pnum:SetVisible(false)
	for i=1,46,1 do listPageTextFrames[i]:SetVisible(false) end
	-- display details page
	
	-- name plate
	name_plate:SetText(name)
	name_plate:SetVisible(true)
	name_plate:ResizeToText()
	
	name_plate:SetPoint("TOPLEFT", context, "TOPLEFT", 237-(name_plate:GetFullWidth()/2), 42)	
	calling_plate:SetText(BOTF_DB[name].calling:gsub("^%l", string.upper) .. " - Level " .. BOTF_DB[name].level)
	calling_plate:SetVisible(true)
	calling_plate:ResizeToText()
	calling_plate:SetPoint("TOPLEFT", context, "TOPLEFT", 237-(calling_plate:GetFullWidth()/2), 70)
	
	--silhouette
	silhouette:SetVisible(true)
	silhouette:SetTexture("BOTF", "media/"..BOTF_DB[name].calling..".png")
	silhouette:ResizeToTexture()

	-- lifetime
	local killingblows = 0
	local assists = 0
	local heals = 0
	local distracts = 0
	local defeats = 0
	-- session
	local s_killingblows = 0
	local s_assists = 0
	local s_heals = 0
	local s_distracts = 0
	local s_defeats = 0
		
	-- lifetime
	killingblows=killingblows+BOTF_DB[name].statistics.killingblows
	assists=assists+BOTF_DB[name].statistics.assists
	heals=heals+BOTF_DB[name].statistics.heals
	distracts=distracts+BOTF_DB[name].statistics.distracts
	defeats=defeats+BOTF_DB[name].statistics.defeats
	-- session
	s_killingblows=s_killingblows+BOTF_DB[name].session_statistics.killingblows
	s_assists=s_assists+BOTF_DB[name].session_statistics.assists
	s_heals=s_heals+BOTF_DB[name].session_statistics.heals
	s_distracts=s_distracts+BOTF_DB[name].session_statistics.distracts
	s_defeats=s_defeats+BOTF_DB[name].session_statistics.defeats
		
	local score = (2*killingblows)+assists+heals+distracts+(-2*defeats)
	local score_pad = 12
	if score>0 then 
		score="+"..score
		score_pad=11
	elseif score<0 then
		score_pad=11
	end
	local lifetime_block = [[Victories: 
		Killing blows: 		]]..string.lpad(killingblows, 12, " ")..[[ 
		Damage assists: 	]]..string.lpad(assists, 12, " ")..[[ 
		Heal assists: 		]]..string.lpad(heals, 12, " ")..[[ 
		Distracts: 			]]..string.lpad(distracts, 12, " ")..[[ 
Defeats:					]]..string.lpad(defeats, 12, " ")..[[ 
Score:  					]]..string.lpad(score, score_pad, " ")..[[
	]]
	local s_score = (2*s_killingblows)+s_assists+s_heals+s_distracts+(-2*s_defeats)
	local s_score_pad = 12
	if s_score>0 then 
		s_score="+"..s_score
		s_score_pad=11
	elseif s_score<0 then
		s_score_pad=11
	end
	local session_block = [[Victories:
		Killing blows: 		]]..string.lpad(s_killingblows, 12, " ")..[[ 
		Damage assists: 	]]..string.lpad(s_assists, 12, " ")..[[ 
		Heal assists: 		]]..string.lpad(s_heals, 12, " ")..[[ 
		Distracts: 			]]..string.lpad(s_distracts, 12, " ")..[[ 
Defeats:					]]..string.lpad(s_defeats, 12, " ")..[[ 
Score:  					]]..string.lpad(s_score, s_score_pad, " ")..[[ 
	]]
	summaryLifetime:SetText(lifetime_block)
	summaryLifetime:SetVisible(true)
	summarySession:SetText(session_block)
	summarySession:SetVisible(true)
end

-------------------------
--[[ PRIVATE METHODS ]]--
-------------------------

-- creates pagesFrame ui
local function init()

	-- create the context
	context = UI.CreateContext("BOTFUIContext")
	
	-- create the book cover
	bookCoverFrame = UI.CreateFrame("Frame", "BOTFUIBookCoverFrame", context)
	bookCoverFrame:SetVisible(false)
	
	-- create the pagesFrame and hide it
	pagesFrame = UI.CreateFrame("Texture", "BOTFUIPagesFrame", bookCoverFrame)
	pagesFrame:SetTexture("BOTF", "media/book_cover.png")
	pagesFrame:ResizeToTexture()
	pagesFrame:SetPoint("TOPLEFT", context, "TOPLEFT")
	pagesFrame:SetLayer(1)
	
	-- close button
	closeButton = UI.CreateFrame("Texture", "BOTFUICloseButton", bookCoverFrame)
	closeButton:SetTexture("BOTF", "media/close_button_1.png")
	closeButton:ResizeToTexture()
	closeButton:SetPoint("TOPLEFT", context, "TOPLEFT", 679, 5)	
	closeButton:SetLayer(2)
	function closeButton.Event:MouseIn()
       closeButton:SetTexture("BOTF", "media/close_button_2.png")
	end
	function closeButton.Event:MouseOut()
       closeButton:SetTexture("BOTF", "media/close_button_1.png")
	end
	function closeButton.Event:LeftClick()
       BOTF.UI.hide()
	end	
	
	-- botf bm
	botf_bm = UI.CreateFrame("Texture", "BOTFUIBookmark", bookCoverFrame)
	botf_bm:SetTexture("BOTF", "media/botf_boomark_1.png")
	botf_bm:ResizeToTexture()
	botf_bm:SetPoint("TOPLEFT", context, "TOPLEFT", 16, 22)	
	botf_bm:SetLayer(2)
	function botf_bm.Event:MouseIn()
       botf_bm:SetTexture("BOTF", "media/botf_boomark_2.png")
	end
	function botf_bm.Event:MouseOut()
       botf_bm:SetTexture("BOTF", "media/botf_boomark_1.png")
	end
	function botf_bm.Event:LeftClick()
       BOTF.UI.showSummaryPage()
	end
	
	-- list bm
	list_bm = UI.CreateFrame("Texture", "BOTFUIBookmark", bookCoverFrame)
	list_bm:SetTexture("BOTF", "media/list_boomark_1.png")
	list_bm:ResizeToTexture()
	list_bm:SetPoint("TOPLEFT", context, "TOPLEFT", 737, 71)
	list_bm:SetLayer(2)
	function list_bm.Event:MouseIn()
       list_bm:SetTexture("BOTF", "media/list_boomark_2.png")
	end
	function list_bm.Event:MouseOut()
       list_bm:SetTexture("BOTF", "media/list_boomark_1.png")
	end
	function list_bm.Event:LeftClick()
       BOTF.UI.showListPage()
	end
	
	-- detail bm
	detail_bm = UI.CreateFrame("Texture", "BOTFUIBookmark", bookCoverFrame)
	detail_bm:SetTexture("BOTF", "media/detail_boomark_1.png")
	detail_bm:ResizeToTexture()
	detail_bm:SetPoint("TOPLEFT", context, "TOPLEFT", 743, 129)	
	detail_bm:SetLayer(2)
	
	-- create summaryLifetime
	summaryLifetime = UI.CreateFrame("Text", "BOTFUISummaryLifetime", bookCoverFrame)
	summaryLifetime:SetWidth(260)
	summaryLifetime:SetHeight(180)
    summaryLifetime:SetBackgroundColor(1,0,0,1)
	summaryLifetime:SetPoint("TOPLEFT", context, "TOPLEFT", 443, 137)	
	summaryLifetime:SetLayer(2)	
	summaryLifetime:SetText("")
	summaryLifetime:SetFontSize(14)
	summaryLifetime:SetFontColor(0.4,0.3,0.3,0.8)
	summaryLifetime:SetVisible(false)
	
	-- create summarySession
	summarySession = UI.CreateFrame("Text", "BOTFUISummarySession", bookCoverFrame)
	summarySession:SetWidth(260)
	summarySession:SetHeight(113)
	summarySession:SetPoint("TOPLEFT", context, "TOPLEFT", 443, 345)	
	summarySession:SetLayer(2)	
	summarySession:SetText("")
	summarySession:SetFontSize(14)
	summarySession:SetFontColor(0.4,0.3,0.3,0.8)
	summarySession:SetVisible(false)
	
	-- create list header
	listPageTextHeader1 = UI.CreateFrame("Text", "BOTFUIListPageTextHeader1", bookCoverFrame)
	listPageTextHeader1:SetWidth(288)
	listPageTextHeader1:SetHeight(23)
	listPageTextHeader1:SetPoint("TOPLEFT", context, "TOPLEFT", 93, 65)	
	listPageTextHeader1:SetLayer(2)	
	listPageTextHeader1:SetText("   Name			     Calling  Level    Score")
	listPageTextHeader1:SetFontSize(14)
	listPageTextHeader1:SetFontColor(0.4,0.3,0.3,0.8)
	listPageTextHeader1:SetVisible(false)
	listPageTextHeader2 = UI.CreateFrame("Text", "BOTFUIListPageTextHeader2", bookCoverFrame)
	listPageTextHeader2:SetWidth(288)
	listPageTextHeader2:SetHeight(23)
	listPageTextHeader2:SetPoint("TOPLEFT", context, "TOPLEFT", 426, 65)	
	listPageTextHeader2:SetLayer(2)	
	listPageTextHeader2:SetText("   Name			     Calling  Level    Score")
	listPageTextHeader2:SetFontSize(14)
	listPageTextHeader2:SetFontColor(0.4,0.3,0.3,0.8)
	listPageTextHeader2:SetVisible(false)
	
	-- create listing frames
	for i=1,46,1 do 
		local frame = UI.CreateFrame("Text", "BOTFUIListPageTextFrame"..i, bookCoverFrame)
		frame:SetWidth(288)
		frame:SetHeight(23)
		local y = 0
		local x = 0
		if i<= 23 then
			x=93
			y=70+(i*15)
		else
			x=426
			y=70+((i-23)*15)		
		end
		frame:SetPoint("TOPLEFT", context, "TOPLEFT", x, y)	
		frame:SetLayer(2)	
		frame:SetText("")
		frame:SetFont("BOTF", "Envy Code R.ttf")
		frame:SetFontSize(15)
		frame:SetFontColor(0.4,0.3,0.3,0.8)
		frame:SetVisible(false)
		function frame.Event:LeftClick()
			-- event handler for left click
		end
		listPageTextFrames[i] = frame
	end
	
	-- create list next/prev arrows
	list_prev = UI.CreateFrame("Texture", "BOTFUIListPrev", bookCoverFrame)
	list_prev:SetTexture("BOTF", "media/prev_button_1.png")
	list_prev:ResizeToTexture()
	list_prev:SetPoint("TOPLEFT", context, "TOPLEFT", 91, 455)
	list_prev:SetLayer(2)
	list_prev:SetVisible(false)
	function list_prev.Event:MouseIn()
       list_prev:SetTexture("BOTF", "media/prev_button_2.png")
	end
	function list_prev.Event:MouseOut()
       list_prev:SetTexture("BOTF", "media/prev_button_1.png")
	end
	list_next = UI.CreateFrame("Texture", "BOTFUIListNext", bookCoverFrame)
	list_next:SetTexture("BOTF", "media/next_button_1.png")
	list_next:ResizeToTexture()
	list_next:SetPoint("TOPLEFT", context, "TOPLEFT", 717, 455)
	list_next:SetLayer(2)
	list_next:SetVisible(false)
	function list_next.Event:MouseIn()
       list_next:SetTexture("BOTF", "media/next_button_2.png")
	end
	function list_next.Event:MouseOut()
       list_next:SetTexture("BOTF", "media/next_button_1.png")
	end
	
	-- create page numbers
	odd_pnum = UI.CreateFrame("Text", "BOTFUIListPageOddNum", bookCoverFrame)
	odd_pnum:SetWidth(100)
	odd_pnum:SetHeight(23)
	odd_pnum:SetPoint("TOPLEFT", context, "TOPLEFT", 203, 455)	
	odd_pnum:SetLayer(2)	
	odd_pnum:SetText("Page x-1")
	odd_pnum:SetFontSize(14)
	odd_pnum:SetFontColor(0.4,0.3,0.3,0.8)
	odd_pnum:SetVisible(false)
	even_pnum = UI.CreateFrame("Text", "BOTFUIListPageEvenNum", bookCoverFrame)
	even_pnum:SetWidth(100)
	even_pnum:SetHeight(23)
	even_pnum:SetPoint("TOPLEFT", context, "TOPLEFT", 548, 455)	
	even_pnum:SetLayer(2)	
	even_pnum:SetText("Page x")
	even_pnum:SetFontSize(14)
	even_pnum:SetFontColor(0.4,0.3,0.3,0.8)
	even_pnum:SetVisible(false)
	
	-- create name plate
	name_plate = UI.CreateFrame("Text", "BOTFUIDetailNamePlate", bookCoverFrame)
	name_plate:SetPoint("TOPLEFT", context, "TOPLEFT", 98, 42)	
	name_plate:SetLayer(2)	
	name_plate:SetText("Name goes here")
	name_plate:ResizeToText()
	name_plate:SetFontSize(20)
	name_plate:SetFontColor(0.8,0.3,0.3,0.8)
	name_plate:SetVisible(false)
	
	-- create calling/level plate
	calling_plate = UI.CreateFrame("Text", "BOTFUIDetailCallingPlate", bookCoverFrame)
	calling_plate:SetPoint("TOPLEFT", context, "TOPLEFT", 98, 76)	
	calling_plate:SetLayer(2)	
	calling_plate:SetText("Calling - Level XX")
	calling_plate:ResizeToText()
	calling_plate:SetFontSize(18)
	calling_plate:SetFontColor(0.4,0.3,0.3,0.8)
	calling_plate:SetVisible(false)
	
	-- silhouette
	silhouette = UI.CreateFrame("Texture", "BOTFUIDetailSilhouette", bookCoverFrame)
	silhouette:SetTexture("BOTF", "media/warrior.png")
	silhouette:ResizeToTexture()
	silhouette:SetPoint("TOPLEFT", context, "TOPLEFT", 159, 104)
	silhouette:SetLayer(2)
	silhouette:SetVisible(false)
	
	-- Register the slash commands
	table.insert(Command.Slash.Register("botf"), {BOTF.UI.show, "BOTF", "Slash command"})
end

--[[ pad a string to the left ]]--
string.lpad = function(str, len, char)
    if char == nil then char = ' ' end
    return string.rep(char, len - #tostring(str)) ..str
end

--[[ pad a string to the right ]]--
string.rpad = function(str, len, char)
    if char == nil then char = ' ' end
    return str .. string.rep(char, len - #tostring(str)) 
end

-- initialisation after addon initialisation
-- table.insert(Event.Addon.Load.End, {function (addon) if addon=="BOTF" then init() end end, "BOTF", "Initialise UI"})
